@@ -23,7 +23,7 @@ class RestletApi(object):
             api_client = ApiClient()
         self.api_client = api_client
 
-    def execute_restlet(self, body_params, method='POST', **kwargs):
+    def execute_restlet(self, path_params, body_params, method='POST', **kwargs):
         all_params = ['script', 'deploy']  # noqa: E501
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -34,7 +34,11 @@ class RestletApi(object):
                 )
             params[key] = val
         del params['kwargs']
-        path_params = {}
+
+        if path_params is not None:
+            path_params = path_params
+        else:
+            path_params = {}
 
         if 'script' in params:
             path_params['script'] = params['script']
